==> SugarCE-5.2.0a.zip: SugarCE-Full-5.2.0a/modules/MergeRecords/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004 - 2009 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
/*********************************************************************************
 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Merge Records',
  'LBL_MODULE_TITLE' => 'Merge Records: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Merge Search',
  'LBL_LIST_FORM_TITLE' => 'Merge List',

  'LBL_LBL_MERGE_RECORDS_STEP_1' => 'Step 1: Find Search Records to Merge With',
  'LBL_AVAIL_FIELDS' => 'Available Fields',
  'LBL_FILTER_COND' => 'Filter Condition',
  'LBL_SELECTED_FIELDS' => 'Selected Fields',
  'LBL_MERGE_RECORDS_WITH' => 'Merge Records With',
  'LBL_MERGE_VALUE_OVER' => 'Merge value over',

  'LBL_NEXT_STEP_TITLE' => 'Move to Next Step[Ctrl+N]',
  'LBL_NEXT_STEP_BUTTON_KEY' => 'N',
  'LBL_NEXT_STEP_BUTTON_LABEL' => 'Next Step >',

  'LBL_PERFORM_MERGE_BUTTON_TITLE' => 'Perform Merge[Ctrl+P]',
  'LBL_PERFORM_MERGE_BUTTON_KEY' => 'P',
  'LBL_PERFORM_MERGE_BUTTON_LABEL' => 'Perform Merge',

  'LBL_SAVE_MERGED_RECORD_BUTTON_TITLE' => 'Save Merge[Ctrl+S]',
  'LBL_SAVE_MERGED_RECORD_BUTTON_KEY' => 'S',
  'LBL_SAVE_MERGED_RECORD_BUTTON_LABEL' => 'Save Merge',

  'LBL_STEP2_FORM_TITLE' => 'Records Found To Merge With:',
  'LBL_SELECT_ERROR'=>'You must make a selection before you can proceed.',
  'LBL_SELECT_PRIMARY'=>'Select primary record for the merge.',
  'LBL_CHANGE_PARENT'=>'Set as primary',
  'LBL_REMOVE_FROM_MERGE'=>'Remove',
  'LBL_DIFF_COL_VALUES'=>'Columns whose value in primary row differs from value in merging rows:',
  'LBL_SAME_COL_VALUES'=>'Columns whose value is similar across all rows:',
  'ERR_EXCEEDS_MAX'=>'You are only allowed to merge a maximum of 5 records. Records exceeding the limit were ignored.',
  'LBL_DELETE_MESSAGE'=>'This action will delete following record(s):',
  'LBL_PROCEED'=>'Proceed ?',
);


?>

==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/MergeRecords/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
/*********************************************************************************
 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Merge Records',
  'LBL_MODULE_TITLE' => 'Merge Records: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Merge Search',
  'LBL_LIST_FORM_TITLE' => 'Merge List',

  'LBL_LBL_MERGE_RECORDS_STEP_1' => 'Find Search Records to Merge With',
  'LBL_AVAIL_FIELDS' => 'Available Fields',
  'LBL_FILTER_COND' => 'Filter Condition',
  'LBL_SELECTED_FIELDS' => 'Selected Fields',
  'LBL_MERGE_RECORDS_WITH' => 'Merge Records With',
  'LBL_MERGE_VALUE_OVER' => 'Merge value over',

  'LBL_NEXT_STEP_TITLE' => 'Move to Next Step[Ctrl+N]',
  'LBL_NEXT_STEP_BUTTON_KEY' => 'N',
  'LBL_NEXT_STEP_BUTTON_LABEL' => 'Next Step >',

  'LBL_PERFORM_MERGE_BUTTON_TITLE' => 'Perform Merge[Ctrl+P]',
  'LBL_PERFORM_MERGE_BUTTON_KEY' => 'P',
  'LBL_PERFORM_MERGE_BUTTON_LABEL' => 'Perform Merge',

  'LBL_SAVE_MERGED_RECORD_BUTTON_TITLE' => 'Save Merge[Ctrl+S]',
  'LBL_SAVE_MERGED_RECORD_BUTTON_KEY' => 'S',
  'LBL_SAVE_MERGED_RECORD_BUTTON_LABEL' => 'Save Merge',

  'LBL_STEP2_FORM_TITLE' => 'Records Found To Merge With:',
  'LBL_SELECT_ERROR'=>'You must make a selection before you can proceed.',
  'LBL_SELECT_PRIMARY'=>'Select primary record for the merge.',
  'LBL_CHANGE_PARENT'=>'Set as primary',
  'LBL_REMOVE_FROM_MERGE'=>'Remove',
  'LBL_DIFF_COL_VALUES'=>'Columns whose value in primary row differs from value in merging rows:',
  'LBL_SAME_COL_VALUES'=>'Columns whose value is similar across all rows:',
  'ERR_EXCEEDS_MAX'=>'You are only allowed to merge a maximum of 5 records. Records exceeding the limit were ignored.',
  'LBL_DELETE_MESSAGE'=>'This action will delete following record(s):',
  'LBL_PROCEED'=>'Proceed ?',
);


?>
